@@ -92,6 +92,15 @@ class ConnectionError(BotoCoreError):
     fmt = 'An HTTP Client failed to establish a connection: {error}'
 
 
+class InvalidIMDSEndpointError(BotoCoreError):
+    fmt = 'Invalid endpoint EC2 Instance Metadata endpoint: {endpoint}'
+
+
+class InvalidIMDSEndpointModeError(BotoCoreError):
+    fmt = ('Invalid EC2 Instance Metadata endpoint mode: {mode}'
+        ' Valid endpoint modes (case-insensitive): {valid_modes}.')
+
+
 class EndpointConnectionError(ConnectionError):
     fmt = 'Could not connect to the endpoint URL: "{endpoint_url}"'
 
@@ -194,6 +203,20 @@ class UnknownEndpointError(BaseEndpointResolverError, ValueError):
         '{service_name} in region {region_name}')
 
 
+class UnknownFIPSEndpointError(BaseEndpointResolverError):
+    """
+    Could not construct a FIPS endpoint.
+
+    :ivar service_name: The name of the service.
+    :ivar region_name: The name of the region.
+    """
+    fmt = (
+        'The provided FIPS pseudo-region "{region_name}" is not known for '
+        'the service "{service_name}". A FIPS compliant endpoint cannot be '
+        'constructed.'
+    )
+
+
 class ProfileNotFound(BotoCoreError):
     """
     The specified configuration profile was not found in the
@@ -472,12 +495,44 @@ class UnsupportedS3ArnError(BotoCoreError):
     )
 
 
+class UnsupportedS3ControlArnError(BotoCoreError):
+    """Error when S3 ARN provided to S3 control parameter is not supported"""
+    fmt = (
+        'S3 ARN "{arn}" provided is invalid for this operation. {msg}'
+    )
+
+
+class InvalidHostLabelError(BotoCoreError):
+    """Error when an invalid host label would be bound to an endpoint"""
+    fmt = (
+        'Invalid host label to be bound to the hostname of the endpoint: '
+        '"{label}".'
+    )
+
+
+class UnsupportedOutpostResourceError(BotoCoreError):
+    """Error when S3 Outpost ARN provided to Bucket parameter is incomplete"""
+    fmt = (
+        'S3 Outpost ARN resource "{resource_name}" provided to "Bucket" '
+        'parameter is invalid. Only ARNs for S3 Outpost arns with an '
+        'access-point sub-resource are supported.'
+    )
+
+
+class UnsupportedS3ConfigurationError(BotoCoreError):
+    """Error when an unsupported configuration is used with access-points"""
+    fmt = (
+        'Unsupported configuration when using S3: {msg}'
+    )
+
+
 class UnsupportedS3AccesspointConfigurationError(BotoCoreError):
     """Error when an unsupported configuration is used with access-points"""
     fmt = (
         'Unsupported configuration when using S3 access-points: {msg}'
     )
 
+
 class InvalidEndpointDiscoveryConfigurationError(BotoCoreError):
     """Error when invalid value supplied for endpoint_discovery_enabled"""
     fmt = (
@@ -485,6 +540,14 @@ class InvalidEndpointDiscoveryConfigurationError(BotoCoreError):
         'Expected one of ("true", "false", "auto") but got {config_value}.'
     )
 
+
+class UnsupportedS3ControlConfigurationError(BotoCoreError):
+    """Error when an unsupported configuration is used with S3 Control"""
+    fmt = (
+        'Unsupported configuration when using S3 Control: {msg}'
+    )
+
+
 class InvalidRetryConfigurationError(BotoCoreError):
     """Error when invalid retry configuration is specified"""
     fmt = (
@@ -558,6 +621,10 @@ class MD5UnavailableError(BotoCoreError):
     fmt = "This system does not support MD5 generation."
 
 
+class MissingDependencyException(BotoCoreError):
+    fmt = "Missing Dependency: {msg}"
+
+
 class MetadataRetrievalError(BotoCoreError):
     fmt = "Error retrieving metadata: {error_msg}"
 
@@ -598,3 +665,9 @@ class CapacityNotAvailableError(BotoCoreError):
     fmt = (
         'Insufficient request capacity available.'
     )
+
+
+class InvalidProxiesConfigError(BotoCoreError):
+    fmt = (
+        'Invalid configuration value(s) provided for proxies_config.'
+    )
